# Contributing

Thank you for contributing to the goodness of this project.

## Creating Issues

If this is a bug:

1. Describe the failure.
2. Include reproduction steps.
3. Include the expected result.

If this is a feature request:

1. Describe the feature.
2. Provide a user story. (As a ___, I need ___ so that I can ___.)
3. Describe the benefits of the feature.

## Submitting Patches

When you submit a patch, please:

1. Include test steps.
2. If possible, please provide unit tests.
3. If possible, please provide functional tests.

## Development Environment Setup

### First Install Drupal 10 or 11

Before you check out this code, install Drupal locally using
[ddev](https://drupalize.me/tutorial/install-drupal-locally-ddev).

```shell
mkdir drupal-vite-react-generator/
cd drupal-vite-react-generator
```

If you have to start over remove the Drupal dependencies first.

```shell
rm -rf web composer.json composer.lock vendor .ddev .editorconfig .gitattributes
```

#### Drupal 10

```shell
mkdir drupal-vite-react-generator-d10
cd drupal-vite-react-generator-d10
ddev config --project-type drupal10 --docroot web
ddev get add-on ddev/ddev-selenium-standalone-chrome
```

Make sure the PHP version in the `.ddev/config.yml` file is set to 8.3 or
greater.

```shell
ddev start
ddev composer create drupal/recommended-project:^10.3 -y
ddev composer require --dev drush/drush drupal/core-dev:^10.3 -y
ddev drush site:install --account-name=admin --account-pass=admin -y
ddev restart
```

#### Drupal 11

```shell
mkdir drupal-vite-react-generator-d11
cd drupal-vite-react-generator-d11
ddev config --project-type drupal --docroot web
ddev add-on get ddev/ddev-selenium-standalone-chrome
ddev start
ddev composer create drupal/recommended-project -y
ddev composer require --dev drush/drush drupal/core-dev -y
ddev drush site:install --account-name=admin --account-pass=admin -y
ddev restart
```

### Installing This Module

Within the Drupal project's root directory, clone this repository.

> The project's root directory is either `drupal-vite-react-generator-d10` or
> `drupal-vite-react-generator-d11`.

Now, create the "contrib modules" directory, symlink this module,
install its dependencies, and add it to Drupal.

```shell
mkdir web/modules/contrib
cd web/modules/contrib
git clone git@git.drupal.org:project/vite_react_generator.git
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator \
  composer install
ddev drush pm:install vite_react_generator
```

## Updating the Templates

> See
> [Scaffolding Your First Vite Project](https://vitejs.dev/guide/#scaffolding-your-first-vite-project).

Execute the following to install React with Vite
for "React with Babel" and "React with SWC."

```shell
source templates/init.sh
```

## Testing

To run the PHPUnit tests, execute:

### To Run All the Tests

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator \
  bash ./scripts/all-tests.sh
```

### To Run the Unit Tests

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator \
  bash ./scripts/unit-tests.sh
```

### To Run the Functional Tests

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator \
  bash ./scripts/functional-tests.sh
```

### To Run PHPCS

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator \
  composer run-script phpcs
```

### To Run PHPCBF

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator \
  composer run-script phpcbf
```

---

The Exploratorium is a 501(c)(3) nonprofit organization.
Our tax ID #: 94-1696494

https://www.exploratorium.edu
