import { fileURLToPath, URL } from 'node:url';

import commonjs from '@rollup/plugin-commonjs';
import react from '@vitejs/plugin-react-swc';
import drupalInterfaceTranslations from 'rollup-plugin-drupal-interface-translations';
import drupalSdcGenerator from 'rollup-plugin-drupal-sdc-generator';
import injectProcessEnv from 'rollup-plugin-inject-process-env';
import { defineConfig } from 'vite';

// https://vitejs.dev/config/
export default defineConfig(({ command, mode }) => {
  // eslint-disable-next-line no-undef
  const { env } = process;

  return {
    root: 'js',
    base: command === 'serve' ? '/' : './',
    plugins: [react()],
    build: {
      outDir: '../components/bar',
      sourcemap: mode === 'development',
      minify: false,
      emptyOutDir: true,
      copyPublicDir: false,
      rollupOptions: {
        output: {
          entryFileNames: '[name].js',
          chunkFileNames: '[name]-[hash].js',
          assetFileNames: '[name].[ext]',
        },
        plugins: [
          injectProcessEnv({
            NODE_ENV: env.NODE_ENV,
          }),
          commonjs(),
          drupalInterfaceTranslations(),
          drupalSdcGenerator(),
        ],
      },
      lib: {
        formats: ['es'],
        entry: {
          'bar': fileURLToPath(
            new URL('js/src/main.jsx', import.meta.url),
          ),
        },
      },
    },
  };
});
