<?php

namespace Drupal\Tests\vite_react_generator\Unit;

use Drupal\vite_react_generator\Drush\Generators\Validator\ComponentName;
use PHPUnit\Framework\TestCase;

/**
 * Test for Drush\Generators\Validator\ComponentName.
 *
 * @group vite_react_generator
 */
final class ComponentNameTest extends TestCase {

  /**
   * Test callback.
   *
   * @dataProvider dataProvider()
   */
  public function test(mixed $component_name, ?\UnexpectedValueException $exception): void {
    if ($exception) {
      $this->expectExceptionObject($exception);
    }
    self::assertSame($component_name, (new ComponentName())($component_name));
  }

  /**
   * Test data provider.
   *
   * @returns array
   *   The dataset for the test case.
   */
  public function dataProvider(): array {
    $exception = new \UnexpectedValueException('The value is not correct component machine name.');
    return array_reduce([
      ['snake_case_here', NULL],
      ['ends_with_number123', NULL],
      ['UPPER_CASE', $exception],
      ['123begins_with_number', $exception],
      ['with.dot', $exception],
      [' not_trimmed ', $exception],
      ['Hello world ', $exception],
      ['ends_with_underscore_', $exception],
      ['', $exception],
      ['foo*&)(*&@#()*&@#bar', $exception],
      [TRUE, $exception],
      [NULL, $exception],
      [[], $exception],
      [new \stdClass(), $exception],
    ], static function ($carry, $item) {
      $carry[] = $item;
      if (is_string($item[0]) && strpos($item[0], '_')) {
        $carry[] = [str_replace('_', '-', $item[0]), $item[1]];
      }
      return $carry;
    }, []);
  }

}
