<?php

namespace Drupal\Tests\vite_react_generator\Unit;

use Drupal\vite_react_generator\Drush\Generators\Validator\RequiredComponentName;
use PHPUnit\Framework\TestCase;

/**
 * Test for Drush\Generators\Validator\RequiredComponentName.
 *
 * @group vite_react_generator
 */
final class RequiredComponentNameTest extends TestCase {

  /**
   * Test callback.
   *
   * @dataProvider dataProvider()
   */
  public function test(mixed $component_name, ?\UnexpectedValueException $exception): void {
    if ($exception) {
      $this->expectExceptionObject($exception);
    }
    self::assertSame($component_name, (new RequiredComponentName())($component_name));
  }

  /**
   * Test data provider.
   *
   * @returns array
   *   The dataset for the test case.
   */
  public function dataProvider(): array {
    $mn_exception = new \UnexpectedValueException('The value is not correct component machine name.');
    $rq_exception = new \UnexpectedValueException('The value is required.');
    return array_reduce([
      ['snake_case_here', NULL],
      ['ends_with_number123', NULL],
      ['UPPER_CASE', $mn_exception],
      ['123begins_with_number', $mn_exception],
      ['0', $mn_exception],
      ['', $rq_exception],
      [NULL, $rq_exception],
      [FALSE, $mn_exception],
      [TRUE, $mn_exception],
    ], static function ($carry, $item) {
      $carry[] = $item;
      if (is_string($item[0]) && \strpos($item[0], '_')) {
        $carry[] = [str_replace('_', '-', $item[0]), $item[1]];
      }
      return $carry;
    }, []);
  }

}
